# koolstof

![Tests](https://github.com/mvdh7/koolstof/workflows/Tests/badge.svg)
[![Coverage](https://github.com/mvdh7/koolstof/blob/main/.misc/coverage.svg)](https://github.com/mvdh7/koolstof/blob/main/.misc/coverage.txt)
[![PyPI version](https://img.shields.io/pypi/v/koolstof.svg?style=popout)](https://pypi.org/project/koolstof/)
[![DOI](https://img.shields.io/badge/DOI-10.5281%2Fzenodo.3999292-informational)](https://doi.org/10.5281/zenodo.3999292)
[![Docs](https://readthedocs.org/projects/koolstof/badge/?version=latest&style=flat)](https://koolstof.readthedocs.io/en/latest/)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Miscellaneous tools for marine carbonate chemistry and other such things.

**Install:**

    pip install koolstof
    
**Import:**

```python
import koolstof as ks
```

**Find current version:**

```python
ks.hello()
```

**Citation:**

> Humphreys, M. P., Delaigue, L. and Ourradi, Y. (2024).  Miscellaneous Python tools for marine carbonate chemistry: koolstof.  *Zenodo*.  [doi:10.5281/zenodo.3999292](https://doi.org/10.5281/zenodo.3999292).
